from typing import final

from cow.web.application import BaseLunaApplicationCtx, LunaApplication as _LunaApplication
from cow.web.middlewares import sendToMonitoringMiddleware
from luna3.client import Luna3Session
from luna3.settings import HTTPSettings
from sanic import HTTPResponse

from .configs.configs.services import SettingsLambdaUnit
from .configs.configs.settings.classes import ServiceAddressSettings, ServiceTimeoutsSettings
from .request import HandlersAppRequest, StandaloneLambdaRequest


class FakeManager:
    """Fake plugin manager"""

    @classmethod
    async def shutdown(cls):
        """Prevent default luna-application behaviour"""


class CtxClass(BaseLunaApplicationCtx):
    """Empty context class for lambda application"""

    pluginManager = FakeManager
    lambdaVersion: int = 1
    luna3Session: Luna3Session | None


async def lambdaVersionMiddleware(request: HandlersAppRequest | StandaloneLambdaRequest, response: HTTPResponse):
    """
    Monitoring middleware. Generate a request point and error point and send them to app monitoring.

    Args:
        request: request
        response: response
    """
    response.headers["Lambda-Version"] = request.app.ctx.lambdaVersion


def getServiceClientKwargs(addressSetting: ServiceAddressSettings, timeoutSettings: ServiceTimeoutsSettings) -> dict:
    """Get service client kwargs"""
    return {
        "origin": addressSetting.origin,
        "api": addressSetting.apiVersion,
        "totalTimeout": timeoutSettings.totalTimeout,
        "connectTimeout": timeoutSettings.connectTimeout,
        "sockConnectTimeout": timeoutSettings.sockConnectTimeout,
        "sockReadTimeout": timeoutSettings.sockReadTimeout,
        "asyncRequest": True,
    }


class BaseLambdaApp(_LunaApplication):
    """Base for lambda application"""

    @final
    def __init__(self, serviceName: str, lambdaVersion: int, lambdaType: str):
        CtxClass.lambdaVersion = lambdaVersion
        super().__init__(
            apiVersion=1,
            configClass=SettingsLambdaUnit,
            defaultPort=8000,
            ctxClass=CtxClass,
            requestClass=HandlersAppRequest if lambdaType == "handlers" else StandaloneLambdaRequest,
        )
        self.ctx.serviceConfig.monitoring.sendData = 0
        middleware2Remove = [row for row in list(self.response_middleware) if row.func == sendToMonitoringMiddleware][0]
        self.response_middleware.remove(middleware2Remove)
        self.response_middleware.append(lambdaVersionMiddleware)
        self.ctx.luna3Session = None
        self.ctx.lambdaType = lambdaType

    async def onStart(self):
        """Startup actions"""

    async def onShutdown(self):
        """Shutdown actions"""

    @final
    async def shutdown(self):
        await self.onShutdown()

    @final
    async def initialize(self):
        """Description see :func:`~_LunaApplication.initialize`"""
        self.ctx.luna3Session = Luna3Session(**self.getLuna3Kwargs(self.ctx.serviceConfig))
        return await self.onStart()

    @staticmethod
    def getLuna3Kwargs(config: SettingsLambdaUnit):
        lunaKwargs = {
            "facesSettings": HTTPSettings(
                **getServiceClientKwargs(addressSetting=config.facesAddress, timeoutSettings=config.facesTimeouts),
            ),
            "handlersSettings": HTTPSettings(
                **getServiceClientKwargs(
                    addressSetting=config.handlersAddress, timeoutSettings=config.handlersTimeouts
                ),
            ),
        }
        if config.additionalServicesUsage.lunaImageStore:
            lunaKwargs.update(
                {
                    "faceSampleStoreSettings": HTTPSettings(
                        **getServiceClientKwargs(
                            addressSetting=config.faceSamplesStorage, timeoutSettings=config.faceSamplesStorageTimeouts
                        ),
                    ),
                    "bodySampleStoreSettings": HTTPSettings(
                        **getServiceClientKwargs(
                            addressSetting=config.bodySamplesStorage, timeoutSettings=config.bodySamplesStorageTimeouts
                        ),
                    ),
                    "imageOriginStoreSettings": HTTPSettings(
                        **getServiceClientKwargs(
                            addressSetting=config.imageOriginStorage, timeoutSettings=config.imageOriginStorageTimeouts
                        ),
                    ),
                }
            )
        if config.additionalServicesUsage.lunaEvents:
            lunaKwargs["eventSettings"] = HTTPSettings(
                **getServiceClientKwargs(addressSetting=config.eventsAddress, timeoutSettings=config.eventsTimeouts),
            )
        if config.additionalServicesUsage.lunaMatcherProxy:
            lpmAddress, lpmTimeouts = config.matcherProxyAddress, config.matcherProxyTimeouts
        else:
            lpmAddress, lpmTimeouts = config.pythonMatcherAddress, config.pythonMatcherTimeouts
        lunaKwargs["pythonMatcherSettings"] = HTTPSettings(
            **getServiceClientKwargs(addressSetting=lpmAddress, timeoutSettings=lpmTimeouts)
        )
        return lunaKwargs
