from pathlib import Path
from typing import Tuple

from cow.errors.errors import Error
from cow.errors.exception import VLException
from cow.web.docs_handler import SpecDocumentsHandler
from cow.web.handlers import BaseHandler
from lambda_main import main
from sanic import HTTPResponse

from .exceptions import UserException


class Handler(BaseHandler):
    """Lambda application handler"""

    async def post(self) -> HTTPResponse:
        try:
            result: dict = await main(self.request)
        except UserException as exc:
            raise VLException(Error.LambdaError.format(exc.errorText), exc.statusCode, False)
        except Exception as exc:
            raise VLException(Error.LambdaError.format(str(exc)), 500, False)
        return self.success(201, outputJson=result)


class HealthCheckHandler(BaseHandler):
    """Lambda healthcheck handler"""

    async def get(self) -> HTTPResponse:
        return self.success(204)


class SpecDocHandler(SpecDocumentsHandler):
    """
    Handler for getting openapi documentations from static directory
    """

    def getDataFromStatic(self, extension: str) -> Tuple[str, bytes]:
        """
        Get file body from a static directory with the specified extension

        Args:
            extension: extension for document file (html or yml)

        Returns:
            tuple (filename, document body)
        """
        STATIC_ROOT = Path(__file__).parent / "static"
        if STATIC_ROOT.exists():
            for posixPath in STATIC_ROOT.iterdir():
                if "lambda" + extension == posixPath.name:
                    data = posixPath.read_bytes()
                    return posixPath.name, data
            raise VLException(Error.DocumentNotFoundError, 500, isCriticalError=False)
        raise VLException(Error.StaticNotFoundError, 500, isCriticalError=False)
