from argparse import ArgumentParser, ArgumentTypeError

from cow.utils.check_connection import (
    checkConnectionToLunaEvents,
    checkConnectionToLunaFaces,
    checkConnectionToLunaHandlers,
    checkConnectionToLunaImageStore,
    checkConnectionToLunaPythonMatcher,
)

from .configs.configs.services import SettingsLambdaUnit
from .configs.configs.settings.classes import ImageStoreAddressSettings, ServiceAddressSettings, ServiceTimeoutsSettings


def positiveInt(value):
    """Positive integer getter"""
    ivalue = int(value)
    if ivalue <= 0:
        raise ArgumentTypeError("%s is an invalid positive int value" % value)
    return ivalue


def getParsedCMDArgs():
    """Get parsed cmd args"""
    parser = ArgumentParser(description="Lambda application", add_help=False)
    parser.add_argument("--name", default="lambda-unique-name", type=str, help="unique lambda name")
    parser.add_argument("--version", default=1, type=positiveInt, help="lambda version")
    parser.add_argument("--lambda-type", default="handlers", choices=["handlers", "standalone"], help="lambda type")

    cmdArgs, _ = parser.parse_known_args()
    return cmdArgs


def getChecks4StandaloneLambda(config: SettingsLambdaUnit):
    """Check for standalone lambda"""
    return []


def getServiceClientKwargs(addressSetting: ServiceAddressSettings, timeoutSettings: ServiceTimeoutsSettings) -> dict:
    """Get handlers client kwargs"""
    return {
        "origin": addressSetting.origin,
        "apiVersion": addressSetting.apiVersion,
        "totalTimeout": timeoutSettings.totalTimeout,
        "connectTimeout": timeoutSettings.connectTimeout,
        "sockConnectTimeout": timeoutSettings.sockConnectTimeout,
        "sockReadTimeout": timeoutSettings.sockReadTimeout,
        "asyncCheck": True,
    }


def getLISClientKwargs(addressSetting: ImageStoreAddressSettings, timeoutSettings: ServiceTimeoutsSettings) -> dict:
    """Get LIS client kwargs"""
    return {
        "origin": addressSetting.origin,
        "apiVersion": addressSetting.apiVersion,
        "bucket": addressSetting.bucket,
        "totalTimeout": timeoutSettings.totalTimeout,
        "connectTimeout": timeoutSettings.connectTimeout,
        "sockReadTimeout": timeoutSettings.sockReadTimeout,
        "sockConnectTimeout": timeoutSettings.sockConnectTimeout,
        "asyncCheck": True,
    }


def getChecks4HandlersLambda(config: SettingsLambdaUnit):
    """Check for handlers labmda"""
    checks = [
        checkConnectionToLunaFaces(
            **getServiceClientKwargs(addressSetting=config.facesAddress, timeoutSettings=config.facesTimeouts),
        ),
        checkConnectionToLunaHandlers(
            **getServiceClientKwargs(addressSetting=config.handlersAddress, timeoutSettings=config.handlersTimeouts),
        ),
    ]
    if config.additionalServicesUsage.lunaImageStore:
        checks.extend(
            [
                checkConnectionToLunaImageStore(
                    postfix="faces_samples",
                    **getLISClientKwargs(
                        addressSetting=config.faceSamplesStorage, timeoutSettings=config.faceSamplesStorageTimeouts
                    ),
                ),
                checkConnectionToLunaImageStore(
                    postfix="bodies_samples",
                    **getLISClientKwargs(
                        addressSetting=config.bodySamplesStorage, timeoutSettings=config.bodySamplesStorageTimeouts
                    ),
                ),
                checkConnectionToLunaImageStore(
                    postfix="images",
                    **getLISClientKwargs(
                        addressSetting=config.imageOriginStorage, timeoutSettings=config.imageOriginStorageTimeouts
                    ),
                ),
            ]
        )
        if config.additionalServicesUsage.lunaEvents:
            checks.append(
                checkConnectionToLunaEvents(
                    **getServiceClientKwargs(
                        addressSetting=config.eventsAddress, timeoutSettings=config.eventsTimeouts
                    ),
                )
            )
        if config.additionalServicesUsage.lunaMatcherProxy:
            checks.append(
                checkConnectionToLunaPythonMatcher(
                    **getServiceClientKwargs(
                        addressSetting=config.matcherProxyAddress, timeoutSettings=config.matcherProxyTimeouts
                    ),
                )
            )
        else:
            checks.append(
                checkConnectionToLunaPythonMatcher(
                    **getServiceClientKwargs(
                        addressSetting=config.pythonMatcherAddress, timeoutSettings=config.pythonMatcherTimeouts
                    ),
                )
            )
    return checks
