from datetime import datetime
from enum import Enum
from typing import Any

import fastjsonschema
from cow.pydantic.types import ValidString
from pydantic.types import ConstrainedFloat, ConstrainedInt, StrictInt
from pydantic.validators import float_validator, number_multiple_validator, number_size_validator

DATETIME_SCHEMA = fastjsonschema.compile({"type": "string", "format": "date-time"})


class SDKImageType(Enum):
    """Image type enum"""

    IMAGE = 0  # usual image
    FACE_WARP = 1  # vl face warp
    BODY_WARP = 2  # vl body warp


class NonStrictInt01(ConstrainedInt):
    """Non strict int in range 0 - 1"""

    ge = 0
    le = 1


class Latitude(ConstrainedFloat):
    """Non strict float latitude"""

    ge = -90.0
    le = 90.0


class Longitude(ConstrainedFloat):
    """Non strict float longitude"""

    ge = -180.0
    le = 180.0


class String36(ValidString):
    """String query getter"""

    min_length = 0
    max_length = 36


class String128(ValidString):
    """String query getter"""

    min_length = 0
    max_length = 128


class _CustomDatetimeMeta(type):
    """Custom datetime meta"""

    def __getitem__(self, param: Any) -> type:
        return type("CustomDatetime", (CustomDatetime,), {"param": param})


class CustomDatetime(metaclass=_CustomDatetimeMeta):
    """
    Custom extended datetime - do not use default if it needs to get attribute as str in ISO-format,
    """

    @classmethod
    def __get_validators__(cls):
        """Get validators - use pydantic default validation, but return attribute as valid datetime str in ISO-format"""
        yield cls.validateDatetime

    @classmethod
    def validateDatetime(cls, value: str | datetime) -> str:
        """
        Validate value is not string
        Args:
            value: input value
        Returns:
            datetime in string format
        """
        try:
            DATETIME_SCHEMA(value)
            return str(value)
        except fastjsonschema.exceptions.JsonSchemaException as e:  # pylint: disable-msg=W0612
            raise ValueError("Invalid datetime")


class _CustomFloatMeta(type):
    """Custom float meta"""

    def __getitem__(self, param: Any) -> type:
        return type("CustomFloat", (CustomFloat,), {"param": param})


class CustomFloat(metaclass=_CustomFloatMeta):
    """
    Custom float - same as default pydantic non-strict float, but not allow to use string as float
    """

    gt: int | float | None = None
    ge: int | float | None = None
    lt: int | float | None = None
    le: int | float | None = None
    param: Any = None
    multiple_of: int | float | None = None

    @classmethod
    def __get_validators__(cls):
        """Get validators - same as pydantic default, but with non-string validation"""
        yield cls.validateNonStr
        yield float_validator
        yield number_size_validator
        yield number_multiple_validator

    @classmethod
    def validateNonStr(cls, value) -> float:
        """Validate value is not string"""
        if isinstance(value, str):
            raise ValueError("value is not a valid float")
        return value


class DetectTs(CustomFloat):
    """User-defined timestamp relative to something, such as the start of a video"""

    ge = 0.0
    le = 158731466399.999


_SDK_INT_MAGIC_NUMBER = 2**30


class SDKInt(StrictInt):
    """Int in range from min to max SDK magic numbers"""

    ge = -_SDK_INT_MAGIC_NUMBER
    le = _SDK_INT_MAGIC_NUMBER
