from cow.pydantic.bases import JsonBaseModel as _BaseModel
from cow.pydantic.types import BoolFromInt01, Latitude, Longitude, OptionalNotNullable, TrackId

from .base import CustomDatetime, DetectTs, NonStrictInt01, SDKImageType, SDKInt, String36, String128


class BoundingBox(_BaseModel):
    """Bounding box schema"""

    # x coordinate of bounding box (from -2**30 to 2**30)
    x: SDKInt
    # y coordinate of bounding box (from -2**30 to 2**30)
    y: SDKInt
    # width of bounding box (from -2**30 to 2**30)
    width: SDKInt
    # height of bounding box (from -2**30 to 2**30)
    height: SDKInt


class ImageOrigin(_BaseModel):
    """Image origin"""

    # image body as bytes
    body: bytes
    # image filename (if present)
    filename: str | None = OptionalNotNullable()
    # image content type (if present)
    contentType: str | None = OptionalNotNullable()


class EventSource(_BaseModel):
    """Image schema"""

    # image body as bytes
    body: bytes
    # image filename (if present)
    filename: str | None = OptionalNotNullable()
    # image content type
    contentType: str
    # face bounding boxes (if present)
    faceBoundingBoxes: list[BoundingBox] | None = OptionalNotNullable()
    # body bounding boxes (if present)
    bodyBoundingBoxes: list[BoundingBox] | None = OptionalNotNullable()
    # image detect time (if present)
    detectTime: CustomDatetime | None = OptionalNotNullable()
    # image detect timestampt (if present)
    detectTs: DetectTs | None = OptionalNotNullable()
    # image origin (if present)
    imageOrigin: ImageOrigin | str | None = OptionalNotNullable()
    # meta information provided by user (if present)
    meta: dict | None = OptionalNotNullable()


class EventsSourceSchema(_BaseModel):
    """Events source schema"""

    # images list
    images: list[EventSource]
    # meta information provided by user (if present)
    meta: dict | None = OptionalNotNullable()

    # image type (usual image/face/body warp)
    imageType: SDKImageType = SDKImageType.IMAGE
    # whether to aggregate attributes
    aggregateAttributes: NonStrictInt01 = 0
    # latitude (from -90 to 90) (if present)
    latitude: Latitude | None = None
    # latitude (from -180 to 180) (if present)
    longitude: Longitude | None = None
    # street (if present)
    street: String36 | None = None
    # house number  (if present)
    houseNumber: String36 | None = None
    # district (if present)
    district: String36 | None = None
    # area (if present)
    area: String36 | None = None
    # cite (if present)
    city: String36 | None = None
    # source (if present)
    source: String128 | None = None
    # tags (if present)
    tags: list[String36] | None = None
    # user data
    userData: String128 = ""
    # external id
    externalId: String36 = ""
    # track id
    trackId: TrackId | None = None
    # whether to use image exif info
    useExifInfo: BoolFromInt01 = True

    # luna-event time (if present)
    lunaEventTime: CustomDatetime | None = OptionalNotNullable()
    # luna event end time
    lunaEventEndTime: CustomDatetime | None = OptionalNotNullable()
